ClientProvider class abstract

Client provider interface for underlying protocol implementations

Implementers

Constructors

ClientProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
isConnected bool
Check if client is connected
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Close connection to remote server
connect() Future<void>
Connect to the remote server
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(int slaveId, ProtocolDataUnit request) Future<ProtocolDataUnit>
Send request to the remote server
sendPdu(int slaveId, Uint8List pduRequest) Future<Uint8List>
Send PDU request to the remote server
sendRawFrame(Uint8List aduRequest) Future<Uint8List>
Send raw frame to the remote server
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited