DataType enum

Data type for register values.

Inheritance
Available extensions

Values

uint16 → const DataType

16-bit unsigned integer (1 register)

int16 → const DataType

16-bit signed integer (1 register)

uint32 → const DataType

32-bit unsigned integer (2 registers)

int32 → const DataType

32-bit signed integer (2 registers)

float32 → const DataType

32-bit float (2 registers)

float64 → const DataType

64-bit double (4 registers)

bool → const DataType

Boolean (bit value)

string → const DataType

ASCII string (variable registers)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DataType>
A constant List of the values in this enum, in order of their declaration.