LRC class

Longitudinal Redundancy Check for Modbus ASCII

Constructors

LRC()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Get LRC value
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
push(List<int> data) LRC
Push data into sum calculation
reset() LRC
Reset LRC sum
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited