isConnected property
bool
get
isConnected
Check if client is currently connected to the server.
Returns true if connected, false otherwise.
Implementation
bool get isConnected;
Check if client is currently connected to the server.
Returns true if connected, false otherwise.
bool get isConnected;