sendRawFrame method

  1. @override
Future<Uint8List> sendRawFrame(
  1. Uint8List aduRequest
)
override

Send a raw ADU frame.

Lowest-level method for sending raw Application Data Unit frames. Only use this if you need complete control over the protocol.

Parameters:

  • aduRequest: Complete ADU frame (protocol-specific format)

Returns: Response ADU frame

Implementation

@override
Future<Uint8List> sendRawFrame(Uint8List aduRequest) =>
    _provider.sendRawFrame(aduRequest);