toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final name = switch (exceptionCode) {
    exceptionCodeIllegalFunction => 'illegal function',
    exceptionCodeIllegalDataAddress => 'illegal data address',
    exceptionCodeIllegalDataValue => 'illegal data value',
    exceptionCodeServerDeviceFailure => 'server device failure',
    exceptionCodeAcknowledge => 'acknowledge',
    exceptionCodeServerDeviceBusy => 'server device busy',
    exceptionCodeNegativeAcknowledge => 'negative acknowledge',
    exceptionCodeMemoryParityError => 'memory parity error',
    exceptionCodeGatewayPathUnavailable => 'gateway path unavailable',
    exceptionCodeGatewayTargetDeviceFailedToRespond =>
      'gateway target device failed to respond',
    _ => 'unknown',
  };
  return 'modbus: exception \'$exceptionCode\' ($name)';
}