ModbusTCPServer class

Modbus TCP Server implementation

Constructors

ModbusTCPServer({required String host, required int port, required ModbusRequestHandler requestHandler})

Properties

clientCount int
Get number of connected clients
no setter
hashCode int
The hash code for this object.
no setterinherited
isRunning bool
Check if server is running
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<void>
Start the server
stop() Future<void>
Stop the server
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited