ProtocolTCPHeader class
Protocol TCP header
Constructors
- ProtocolTCPHeader({required int transactionId, required int protocolId, required int length, required int slaveId})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
final
- protocolId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slaveId → int
-
final
- transactionId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited