RandomValueGenerator class

Random value generator based on data type

Constructors

RandomValueGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateInRange(double min, double max) double
Generate random value in range
generateValue(DataType dataType) → dynamic
Generate random value for a data type