RegisterType enum
Register type enumeration.
Values
- coil → const RegisterType
-
Coils (read/write bits) - FC 01, 05, 15
- discreteInput → const RegisterType
-
Discrete inputs (read-only bits) - FC 02
- inputRegister → const RegisterType
-
Input registers (read-only 16-bit) - FC 04
- holdingRegister → const RegisterType
-
Holding registers (read/write 16-bit) - FC 03, 06, 16
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RegisterType> - A constant List of the values in this enum, in order of their declaration.