SerialConfig class

Serial port configuration

Constructors

SerialConfig({required String portName, int baudRate = 19200, int dataBits = 8, int stopBits = 1, String parity = 'N', Duration timeout = const Duration(seconds: 1)})
const

Properties

baudRate int
final
dataBits int
final
hashCode int
The hash code for this object.
no setterinherited
parity String
final
portName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopBits int
final
timeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited