SerialPort class abstract

Abstract serial port interface Users should implement this interface using platform-specific libraries such as flutter_libserialport or dart_serial_port

Constructors

SerialPort()

Properties

hashCode int
The hash code for this object.
no setterinherited
isOpen bool
Check if the port is open
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Close the serial port
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() Future<void>
Open the serial port
read(int length) Future<Uint8List>
Read data from the serial port
readUntil(List<int> pattern, {int? maxLength}) Future<Uint8List>
Read data until a specific pattern is found
toString() String
A string representation of this object.
inherited
write(Uint8List data) Future<void>
Write data to the serial port

Operators

operator ==(Object other) bool
The equality operator.
inherited