PointTableConfig class
Point table configuration loaded from YAML
Constructors
-
PointTableConfig({required String name, required int slaveId, required String protocol, String? address, Map<
String, dynamic> ? serialConfig, required List<RegisterDefinition> registers, int? pollInterval})
Properties
- address → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- pollInterval → int?
-
final
- protocol → String
-
final
-
registers
→ List<
RegisterDefinition> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serialConfig
→ Map<
String, dynamic> ? -
final
- slaveId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toRegisterMap(
) → RegisterMap - Convert to RegisterMap
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromFile(
String filePath) → Future< PointTableConfig> - Load from YAML file
-
fromYaml(
dynamic yaml) → PointTableConfig - Load from YAML object